import * as webpack from 'webpack';
export declare type ConsoleRemotePluginOptions = Partial<{
    /**
     * Validate the plugin's `package.json` file schema?
     *
     * This controls the validation of `consolePlugin` object within the plugin's package
     * manifest using the `plugin-package.json` schema. The `consolePlugin` object should
     * exist and contain valid Console dynamic plugin metadata.
     *
     * @default true
     */
    validatePackageSchema: boolean;
    /**
     * Validate Console provided shared modules which are consumed by the plugin?
     *
     * Console provided shared modules are reflected as `dependencies` in the core plugin
     * SDK package manifest. For each shared module where a fallback version is not allowed,
     * check that the version consumed by the plugin satisfies the expected semver range as
     * declared in the core plugin SDK package manifest.
     *
     * @default true
     */
    validateSharedModules: boolean;
    /**
     * Validate the plugin's `console-extensions.json` file schema?
     *
     * This controls the validation of extension declarations using the `console-extensions.json`
     * schema.
     *
     * @default true
     */
    validateExtensionSchema: boolean;
    /**
     * Validate the integrity of extensions declared in `console-extensions.json` file?
     *
     * This controls whether to use `ExtensionValidator` to check extension declarations:
     * - each exposed module must have at least one code reference
     * - each code reference must point to a valid webpack module export
     *
     * @default true
     */
    validateExtensionIntegrity: boolean;
}>;
/**
 * Generates Console dynamic plugin remote container and related assets.
 *
 * Default configuration for modules shared between the Console application and its dynamic plugins:
 * - shared modules are treated as singletons
 * - plugins won't bring their own fallback version of shared modules
 *
 * If you're facing `ExtensionValidator` related issues, set the `validateExtensionIntegrity` option
 * to `false` or pass `CONSOLE_PLUGIN_SKIP_EXT_VALIDATOR=true` env. variable to your webpack command.
 *
 * @see {@link sharedPluginModulesMetadata}
 */
export declare class ConsoleRemotePlugin {
    private readonly options;
    private readonly pkg;
    constructor(options?: ConsoleRemotePluginOptions);
    apply(compiler: webpack.Compiler): void;
}
